##  Viewing and Managing Transformation Items
To view all Transformations affecting an Application or any specific Fact Sheet, navigate directly to the Fact Sheet's Transformation tab. In the Transformation tab of the Fact Sheets, you can view the initiatives in progress and edit or execute any Transformations.
The transformations explorer provides an additional way to gain an overview of all existing transformation items. Learn more about it in [Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to use the transformations explorer to get visibility into all of your transformation activities. Use it to streamline planning and execution with features like scope-based filtering and bulk actions.").
